@@ -13,7 +13,7 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-  $Id: contour.c,v 1.30 2004/07/28 03:52:42 sarod Exp $
+  $Id: contour.c,v 1.32 2004/10/25 04:43:05 sarod Exp $
 */
 
 /* Werner Hoch provided code to produce color in EPS files
@@ -40,8 +40,6 @@ int current_plotting_contour; /* number in z array */
 MY_DOUBLE max_gradient=0.01; /* initially a low one */
 
 
-
-
 /* contour plotting */
 static int 
 plot_contour(triangle *t, double potential)
@@ -1085,6 +1083,30 @@ print_mesh_ascii(const char* filename)
 
 }
 
+/* printing potentials as ACII file*/
+void
+print_potential(const char* filename)
+{
+/* file format
+  first line: no. of points
+  other lines: point number, x, y, potential
+*/
+
+  FILE *outf;
+  int i;
+  if ((outf=fopen(filename,"w"))==NULL){
+    fprintf(stderr,"%s: %d: could not open file %s\n",__FILE__,__LINE__,filename);
+    return;	
+   }
+  
+  fprintf(outf,"%d\n",M.count);
+  for ( i = 0; i < M.count; i++ ) {
+       fprintf(outf,"%d "MDF" "MDF" "MDF"\n",i, (Mx(i))*g_xscale-g_xoff, (My(i))*g_yscale-g_yoff, Mzz(i,current_plotting_contour));
+  }
+  
+  fclose(outf);
+}
+
 
 /* a function to plot the gradient of potential */
 void
@@ -1338,14 +1360,14 @@ if (!gdk_gl_drawable_gl_begin(gldrawable,glcontext))
 		h=2;
 
 /* top, bottom border =h/20 */
- /* left border = w/20, color block=w/3, text=w/2, right border=w/15 */
+ /* left border = w/10, color block=9w/10, right border=w/10 */
 	/* drawing */
 	 dy=(h*0.9)/(GLfloat)contour_levels;
 
   y2=-0.45*h;
 	y1=dy+y2;
   x1=-0.45*w;
-	x2=-0.11*w;
+	x2=-x1;
    glClear(GL_COLOR_BUFFER_BIT);
 #ifdef DEBUG
 	printf("expose_ev: legend: rectangle (%f,%f)--(%f,%f)\n",x1,y1,x2,y2);
@@ -1353,10 +1375,10 @@ if (!gdk_gl_drawable_gl_begin(gldrawable,glcontext))
 
 
 	/* horizontal line */
-	glColor3f(0.0f,0.7f,0.7f);
+	glColor3f(0.0f,0.0f,0.0f);
 	glBegin(GL_LINES);
-	glVertex2d(x2,y2);
-	glVertex2d(x2+0.5*w,y2);
+	glVertex2d(x1,y2);
+	glVertex2d(x1+0.9*w,y2);
 	glEnd();
 
   for (i=0; i<contour_levels; i++) {
@@ -1372,8 +1394,8 @@ if (!gdk_gl_drawable_gl_begin(gldrawable,glcontext))
 	/* horizontal line */
 	glColor3f(0.0f,0.7f,0.7f);
 	glBegin(GL_LINES);
-	glVertex2d(x2,y1);
-	glVertex2d(x2+0.5*w,y1);
+	glVertex2d(x1,y1);
+	glVertex2d(x1+0.0*w,y1);
 	glEnd();
 
 	y1+=dy;
@@ -1388,6 +1410,31 @@ gdk_gl_drawable_gl_end(gldrawable);
  return(TRUE);
 }
 
+/* mouse motion */
+static gboolean
+motion_notify_event(GtkWidget *widget,
+   GdkEventMotion *event,
+   gpointer data) 
+{
+ GtkWidget *label;
+ GLfloat h,y;
+ int i;
+ gchar buf[128];
+ h=widget->allocation.height;
+
+ y=-2*event->y/h+1.0;
+ label=(GtkWidget*)data;
+ /* determine exact contour we are in */
+ i=(int)floor((double)(y+0.9)*(double)contour_levels/1.8);
+ /* sanity check: i has to be in [0,contour_levels-1]*/
+ if ( (i>= 0) && (i<contour_levels)) {
+ g_snprintf(buf,128,"%4.2f",(float)i*(g_maxpot-g_minpot)/(float)contour_levels+g_minpot);
+/* printf("%4.3f\n",(float)i*(g_maxpot-g_minpot)/(float)contour_levels+g_minpot); */
+ gtk_label_set_markup(GTK_LABEL(label),buf);
+ return(TRUE);
+ }
+ return(FALSE);
+}
 
 static gint
 close_legend_window(GtkWidget *widget, GdkEvent *event, gpointer *data)
@@ -1402,10 +1449,10 @@ display_legend_window(void)
   GtkWidget *window;
   GtkWidget *vbox;
   GtkWidget *drawing_area;
+  GtkWidget *legend_label;
 	GdkGLConfig *glconfig;
 
 
-
   /* Try double-buffered visual */
   glconfig = gdk_gl_config_new_by_mode (GDK_GL_MODE_RGB |
 					GDK_GL_MODE_DOUBLE);
@@ -1463,7 +1510,6 @@ display_legend_window(void)
 				GDK_GL_RGBA_TYPE);
 
   gtk_widget_add_events (drawing_area,
-			 GDK_BUTTON_PRESS_MASK      |
 			 GDK_POINTER_MOTION_MASK    |  /* any pointer motion */
 			 GDK_VISIBILITY_NOTIFY_MASK);
 
@@ -1475,15 +1521,22 @@ display_legend_window(void)
   g_signal_connect (G_OBJECT (drawing_area), "expose_event",
 		    G_CALLBACK (expose_event), NULL);
 
-
   gtk_box_pack_start (GTK_BOX (vbox), drawing_area, TRUE, TRUE, 0);
-
   gtk_widget_show (drawing_area);
 
+  /* label to show potential */
+  legend_label=gtk_label_new("000");
+  gtk_label_set_justify(GTK_LABEL(legend_label),GTK_JUSTIFY_CENTER);
+  gtk_box_pack_start(GTK_BOX(vbox),legend_label,FALSE,TRUE,0);
+  gtk_widget_show(legend_label);
+
+  /* connect mouse motion */
+  g_signal_connect (G_OBJECT(drawing_area),"motion_notify_event",
+        G_CALLBACK(motion_notify_event), (gpointer)legend_label);
+
 
   gtk_widget_show(window);
 
-
 }
 
 
