@@ -13,7 +13,7 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-  $Id: dxf.c,v 1.14 2004/07/22 18:56:58 sarod Exp $
+  $Id: dxf.c,v 1.16 2004/10/31 05:24:33 sarod Exp $
 */
 
 
@@ -166,7 +166,7 @@ is_this_edge_on_a_boundary(p0,p1)
 
 
 static int
-read_2_lines_at_a_time (FILE * fp, int *line1, char *line2)
+read_2_lines_at_a_time (FILE * fp, int *line1, char *line2, int line2_length)
 {
   int flag;
   int c, count;
@@ -201,10 +201,21 @@ read_2_lines_at_a_time (FILE * fp, int *line1, char *line2)
 	  line2[count++] = c;
 	}
       /*printf("read (%c) ",c); */
-    }
-  while (1);
-
-  /*printf("read_:%d and %s\n",*line1,line2); */
+    } while (count<line2_length-1);
+    
+    /* if count > line2_length-1 we have overstepped buffer*/
+    if(count==line2_length-1) {
+	   line2[count] = '\0';
+     /* read out the rest of the line */
+     do {
+      if ((c=getc(fp))==EOF) {
+         return(EOF);
+      }
+     } while (c!='\n');
+    } 
+#ifdef DEBUG
+  printf(">>>>>>read_:%d and %s\n",*line1,line2); 
+#endif
   return (count);
 }
 
@@ -232,6 +243,7 @@ read_dxf_file_and_triangulate (const char *filename)
 	/* global edges */
   nedges=0;
 
+
   fp = fopen (filename, "r");
   if (fp == NULL)
     {
@@ -243,7 +255,7 @@ read_dxf_file_and_triangulate (const char *filename)
 		/* global edge array size */
   while (flag != EOF)
     {
-      flag = read_2_lines_at_a_time (fp, &line1, line2);
+      flag = read_2_lines_at_a_time (fp, &line1, line2,20);
       if ((flag != EOF) && (line1 == 0) && !strcmp (line2, "LINE"))
 	{
 #ifdef DEBUG
@@ -252,7 +264,7 @@ read_dxf_file_and_triangulate (const char *filename)
 	  /* new line def found */
 	  do
 	    {
-	      flag = read_2_lines_at_a_time (fp, &line1, line2);
+	      flag = read_2_lines_at_a_time (fp, &line1, line2,20);
 	    }
 	  while ((flag != EOF) && (line1 != 10));
 	  if (flag == EOF)
@@ -268,7 +280,7 @@ read_dxf_file_and_triangulate (const char *filename)
 #endif
 	  do
 	    {
-	      flag = read_2_lines_at_a_time (fp, &line1, line2);
+	      flag = read_2_lines_at_a_time (fp, &line1, line2,20);
 	    }
 	  while ((flag != EOF) && (line1 != 20));
 	  if (flag == EOF)
@@ -283,7 +295,7 @@ read_dxf_file_and_triangulate (const char *filename)
 #endif
 	  do
 	    {
-	      flag = read_2_lines_at_a_time (fp, &line1, line2);
+	      flag = read_2_lines_at_a_time (fp, &line1, line2,20);
 	    }
 	  while ((flag != EOF) && (line1 != 11));
 	  if (flag == EOF)
@@ -298,7 +310,7 @@ read_dxf_file_and_triangulate (const char *filename)
 #endif
 	  do
 	    {
-	      flag = read_2_lines_at_a_time (fp, &line1, line2);
+	      flag = read_2_lines_at_a_time (fp, &line1, line2,20);
 	    }
 	  while ((flag != EOF) && (line1 != 21));
 	  if (flag == EOF)
@@ -326,8 +338,8 @@ read_dxf_file_and_triangulate (const char *filename)
 			}
 	}
     }
-
-  fclose (fp);
+  if (!fp)
+   fclose (fp);
   xmax = -1000;
   xmin = 1000;
   ymax = -1000;
@@ -509,7 +521,9 @@ read_dxf_file_and_triangulate (const char *filename)
 	 * edges on any boundary edge, each element of row will 
 	 * give that edge number. if not -1 
 	 */
+#ifdef DEBUG
   printf("total triangles=%d\n",ntriangles);
+#endif
   if ((triangle_edge_array =(MY_INT**)calloc((size_t)ntriangles,sizeof(MY_INT*)))==0){
 		fprintf(stderr, "%s: %d: no free memory\n", __FILE__,__LINE__);
 		exit(1);
