@@ -13,7 +13,7 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-  $Id: graphics.c,v 1.42 2004/10/18 23:56:30 sarod Exp $
+  $Id: graphics.c,v 1.49 2004/11/17 01:18:59 sarod Exp $
 */
 
 
@@ -24,18 +24,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "types.h"
-
-
-#ifdef USE_GTK
 #include <math.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkgl.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
-#endif /* !USE_GTK */
 
+#include "types.h"
 /* function to interpolate potential within 
    a triangle */
 static MY_DOUBLE
@@ -84,28 +80,28 @@ update_status_bar(char *msg) {
 /* global to update mode label */
 void
 update_mode_label(char *msg) {
-  gchar buf[128];
+  gchar buf[256];
   int eigen_number;
   /* for helmholtz cases we can have 3 times deg of freedom contours */
    eigen_number=current_plotting_contour/3; /* floor by 3 */
 
  /* if we are plotting an eigenvector, we display 
    eigenvalue */
- if ( solve_equation == POISSON ) {
- g_snprintf(buf, 128, "|<span foreground=\"red\">Poisson</span>");
+ if ( solve_equation == POISSON || solve_equation== POISSON_SPARSE ) {
+ g_snprintf(buf, 256, "|<span foreground=\"red\"><small>Poisson    </small></span>");
  gtk_label_set_markup(GTK_LABEL(global_mode_label),buf);
  } else  { /* we have an eigenvalue */
   if (solve_equation == HELMHOLTZ ) {
-   g_snprintf(buf, 128, "|<span foreground=\"red\">Helmholtz(homo) </span>%d:<span foreground=\"blue\">%5.3lf</span>",current_plotting_contour,eig_array[current_plotting_contour]);
+   g_snprintf(buf, 256, "|<span foreground=\"red\"><small>Helmholtz(homo)</small></span>%d:<span foreground=\"blue\">%5.3lf</span>",current_plotting_contour,eig_array[current_plotting_contour]);
   } else if (solve_equation == HELMHOLTZ_INHOMO ) {
 
-   g_snprintf(buf, 128, "|<span foreground=\"red\">Helmholtz(inhomo) </span>%d:<span foreground=\"blue\">%5.3lf</span>",eigen_number,eig_array[eigen_number]);
+   g_snprintf(buf, 256, "|<span foreground=\"red\"><small>Helmholtz(inhomo)</small></span>%d:<span foreground=\"blue\">%5.3lf</span>",eigen_number,eig_array[eigen_number]);
   } else if (solve_equation == HELMHOLTZ_FREQ) {
 
-   g_snprintf(buf, 128, "|<span foreground=\"red\">Helmholtz(freq) </span>%d:<span foreground=\"blue\">%5.3lf</span>",eigen_number,eig_array[eigen_number]);
+   g_snprintf(buf, 256, "|<span foreground=\"red\"><small>Helmholtz(freq) </small></span>%d:<span foreground=\"blue\">%5.3lf</span>",eigen_number,eig_array[eigen_number]);
   } else if (solve_equation == HELMHOLTZ_BETA) {
   
-   g_snprintf(buf, 128, "|<span foreground=\"red\">Helmholtz(beta) </span>%d:<span foreground=\"blue\">%5.3lf</span>",eigen_number,eig_array[eigen_number]);
+   g_snprintf(buf, 256, "|<span foreground=\"red\"><small>Helmholtz(beta) </small></span>%d:<span foreground=\"blue\">%5.3lf</span>",eigen_number,eig_array[eigen_number]);
   }
 
   gtk_label_set_markup(GTK_LABEL(global_mode_label),buf);
@@ -145,7 +141,6 @@ draw_polygon(polygon *poly)
 
 
 /* the  rest is gtkglext stuff */
-#ifdef USE_GTK
 
 /* realize signal handler,
   opengl intialization done here */
@@ -832,10 +827,14 @@ motion_notify_event(GtkWidget *widget,
  if ( current_dag_node ) {
 	 t=(triangle *)current_dag_node->rec;
    if (t->status==LIVE ) {
-   cz=interpolate_potential(Mx(t->p0),My(t->p0),Mzz(t->p0,current_plotting_contour),
+/*   cz=interpolate_potential(Mx(t->p0),My(t->p0),Mzz(t->p0,current_plotting_contour),
     Mx(t->p1),My(t->p1),Mzz(t->p1,current_plotting_contour),
     Mx(t->p2),My(t->p2),Mzz(t->p2,current_plotting_contour),
-    p.x,p.y);
+    p.x,p.y);*/
+ cz=interpolate_potential(Mx(t->p0)*g_xscale-g_xoff,My(t->p0)*g_yscale-g_yoff,Mzz(t->p0,current_plotting_contour),
+    Mx(t->p1)*g_xscale-g_xoff,My(t->p1)*g_yscale-g_yoff,Mzz(t->p1,current_plotting_contour),
+    Mx(t->p2)*g_xscale-g_xoff,My(t->p2)*g_yscale-g_yoff,Mzz(t->p2,current_plotting_contour),
+    cx,cy);
    }
  }
  g_snprintf(buf, 128, "x: <span foreground=\"blue\">%5.3lf</span> y: <span foreground=\"blue\">%5.3lf</span> z: <span foreground=\"blue\">%5.3lf</span>", cx,cy,cz);
@@ -928,7 +927,7 @@ static void
 switch_to_next_eigenmode(GtkWidget *widget)
 {
  /* switch to next eigenmode */
-  if (solve_equation== POISSON ) {
+  if (solve_equation== POISSON || solve_equation == POISSON_SPARSE ) {
    current_plotting_contour=0;
   } else if (solve_equation == HELMHOLTZ ) {
    current_plotting_contour++;
@@ -1194,10 +1193,11 @@ menubar_solve_only_response( gchar *string )
      || (solve_equation == HELMHOLTZ_FREQ)
      || (solve_equation == HELMHOLTZ_BETA)) {
        buildup_hash_table_and_equation(); 
-    } else {
+    } else if(solve_equation==POISSON_SPARSE) {
+				re_number_and_solve_poisson_sparse();
+	  } else {
 				re_number_and_solve_poisson();
-	  } 
-
+    }
 }
 
 
@@ -1533,6 +1533,10 @@ menubar_solve_options_response( gchar *string )
 														G_CALLBACK(menubar_save_cb_equation_type),
 														GINT_TO_POINTER(POISSON));
 						gtk_menu_shell_append(GTK_MENU_SHELL(menu),item);
+						item=make_menu_item("Poisson (Sparse)",
+														G_CALLBACK(menubar_save_cb_equation_type),
+														GINT_TO_POINTER(POISSON_SPARSE));
+						gtk_menu_shell_append(GTK_MENU_SHELL(menu),item);
 						item=make_menu_item("Homogeneous Helmholtz",
 														G_CALLBACK(menubar_save_cb_equation_type),
 														GINT_TO_POINTER(HELMHOLTZ));
@@ -1551,7 +1555,6 @@ menubar_solve_options_response( gchar *string )
 						gtk_menu_shell_append(GTK_MENU_SHELL(menu),item);
 
 
-
 						gtk_option_menu_set_menu(GTK_OPTION_MENU(opt),menu);
 						gtk_option_menu_set_history(GTK_OPTION_MENU(opt),(gint)solve_equation);
 						gtk_box_pack_start(GTK_BOX(box2),opt,TRUE,TRUE,0);
@@ -1782,7 +1785,7 @@ create_window (GdkGLConfig *glconfig)
  window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title(GTK_WINDOW(window),DEFAULT_TITLE);
 
- gtk_container_set_reallocate_redraws(GTK_CONTAINER(window),TRUE);
+ gtk_container_set_reallocate_redraws(GTK_CONTAINER(window),FALSE);
 
  g_signal_connect(G_OBJECT(window), "delete_event",
                   G_CALLBACK(gtk_main_quit),NULL);
@@ -2411,7 +2414,7 @@ create_mesh_grid_window(GdkGLConfig *glconfig)
 	window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(window),"Surf Mesh");
 
-	gtk_container_set_reallocate_redraws(GTK_CONTAINER(window),TRUE);
+	gtk_container_set_reallocate_redraws(GTK_CONTAINER(window),FALSE);
 	/* default signal handler */
   g_signal_connect_swapped(GTK_OBJECT(window),"delete_event",
 	G_CALLBACK(gtk_widget_destroy),(gpointer)window);
@@ -2498,4 +2501,3 @@ display_mesh_grid( GtkWidget *widget )
 		gtk_widget_show(window);
 
 }
-#endif /* !USE_GTK */
