@@ -13,7 +13,7 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-  $Id: pdnmesh.c,v 1.38 2004/10/18 21:10:07 sarod Exp $
+  $Id: pdnmesh.c,v 1.44 2004/11/17 03:30:32 sarod Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -27,17 +27,14 @@
 #include <string.h>
 #include <ctype.h>
 #include <unistd.h>
-#include "types.h"
-
-
-#ifdef USE_GTK
 #include <math.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkgl.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
-#endif /* !USE_GTK */
+
+#include "types.h"
 
 int ntriangles,mouse_responce_flag,windowid;
 DAG_tree dt;
@@ -1118,7 +1115,7 @@ if ((tg2=(triangle *)malloc(sizeof(triangle)))==0) {
 		}
 #endif
 		/* solve mesh */
-  if ( solve_equation!=POISSON ) {
+  if ( solve_equation!=POISSON && solve_equation!=POISSON_SPARSE ) {
   /* number of eigenvectors to be found */
 	if (requested_degree_of_freedom) {
 	 degree_of_freedom=requested_degree_of_freedom; /* global change */
@@ -1136,9 +1133,12 @@ if ((tg2=(triangle *)malloc(sizeof(triangle)))==0) {
      || (solve_equation == HELMHOLTZ_BETA)) {
    buildup_hash_table_and_equation(); 
   }
-  } else { /* POISSON */
+  } else if (solve_equation==POISSON_SPARSE) {
+   re_number_and_solve_poisson_sparse();
+  }  else { /* POISSON */
    re_number_and_solve_poisson();
   }
+
   return(0);
 }
 
@@ -1191,16 +1191,15 @@ print_help(void)
 /*  printf("-v    : be verbose\n");                                         
   printf("-b (val) : set max badness of each triangle to 'val'\n");            
   printf("-s (val) : set splitting priority to 'val'\n");                 
-  printf("-c (val) : set contour levels to 'val'\n");                     
   printf("-l (val) : set max nodes to 'val'\n");
   printf("-r (val) : limit iterations to 'val'\n");
   printf("-conj    : use preconditioned conjugate gradient method to solve\n");
   printf("-nx      : do not go into display mode, dump output to files\n"); 
-  printf("-contours   : display contours by default\n"); 
-  printf("-mesh       : display mesh by default\n"); 
-  printf("-gradient   : display gradient by default\n"); 
   printf("-do      : output data file of mesh as \"data.in\"\n");     */
-	printf("-e (poisson|helmholtz): type of equation to solve\n");
+  printf("-c (val) : set contour levels to 'val'\n");                     
+	printf("-d (contour|grad|fill): display contours,gradient,colourfill by default\n");
+	printf("-e (poisson|helmholtz|helmin|helmk|helmbeta): type of equation to solve\n");
+  printf("-s  : use sparse solver (works only for Poisson Equation)\n");
   printf("-V    : print version\n");
 }
 
@@ -1212,7 +1211,7 @@ print_version(void)
   printf(PACKAGE" comes with ABSOLUTELY NO WARRANTY\n"); 
   printf("This is free software, and you are welcome to redistribute\n");
   printf("it under certain conditions given by GNU GENERAL PUBLIC LICENSE\n");
-  printf("$Id: pdnmesh.c,v 1.38 2004/10/18 21:10:07 sarod Exp $\n"); 
+  printf("$Id: pdnmesh.c,v 1.44 2004/11/17 03:30:32 sarod Exp $\n"); 
 	printf("This is a beta release. Please report bugs to\n");
 	printf(" <"PACKAGE_BUGREPORT">. Thank you.\n");
 }
@@ -1239,9 +1238,15 @@ g_gradient_limit=1000;
 
 solve_equation = POISSON; /* POISSON, HELMHOLTZ */
 
+/* default plotting */
+ plot_mesh=0;
+ plot_cont=0;
+ plot_grad=0;
+ plot_legend=0;
+ 
  update_status_bar("Starting intialization...");
 /* getopt loop */
- while ((c=getopt(argc,argv,"i:e:a:A:vhV"))!=-1) {
+ while ((c=getopt(argc,argv,"i:e:d:a:A:c:svhV"))!=-1) {
 		switch (c) {
 						case 'i':
         if (optarg) {
@@ -1260,24 +1265,51 @@ solve_equation = POISSON; /* POISSON, HELMHOLTZ */
 							   solve_equation=HELMHOLTZ;
 	              } else if( !strcmp(optarg,"poisson")) {
 							   solve_equation=POISSON;
+	              } else if( !strcmp(optarg,"helmin")) {
+							   solve_equation=HELMHOLTZ_INHOMO;
+	              } else if( !strcmp(optarg,"helmk")) {
+							   solve_equation=HELMHOLTZ_FREQ;
+	              } else if( !strcmp(optarg,"helmbeta")) {
+							   solve_equation=HELMHOLTZ_BETA;
 	              } else {
 								fprintf(stderr,"Unknown equation type `%s`.\n",optarg);
 							  }
 							break;
+			      case 'd':
+               if (!strcmp(optarg,"contour")) {
+							   plot_cont=1;
+	              } else if( !strcmp(optarg,"grad")) {
+							   plot_grad=1;
+	              } else if( !strcmp(optarg,"fill")) {
+							   plot_fill=1;
+	              } else {
+								fprintf(stderr,"Unknown display option `%s`.\n",optarg);
+							  }
+							break;
             case 'a':
                g_area_floor=strtod(optarg,0);
                if ( g_area_floor == 0.0f ) {
-								fprintf(stderr,"Invalid value `%s`.\n",optarg);
+								fprintf(stderr,"Invalid value for area `%s`.\n",optarg);
                 g_area_floor=0.001;
                }
              break;
             case 'A':
                g_area_ceil=strtod(optarg,0);
                if ( g_area_ceil== 0.0f ) {
-								fprintf(stderr,"Invalid value `%s`.\n",optarg);
+								fprintf(stderr,"Invalid value for area `%s`.\n",optarg);
                 g_area_ceil=0.005;
                }
              break;
+            case 'c':
+               contour_levels=strtol(optarg,0,0);
+               if ( !contour_levels ) {
+								fprintf(stderr,"Invalid value for contours `%s`.\n",optarg);
+                contour_levels=40;
+               }
+             break;
+           	case 's':
+					  if(solve_equation==POISSON) solve_equation=POISSON_SPARSE;
+            break;
 						case 'h':
 			      print_help();
 						exit(0);
@@ -1297,6 +1329,9 @@ solve_equation = POISSON; /* POISSON, HELMHOLTZ */
 		}
 	}
 
+ if (!plot_cont && !plot_grad && !plot_fill) {
+   plot_cont=1;
+ }
   /* initialize bitree for 100 points intially */
   BIT_init(&M,100);
   /* initialize DAG */
@@ -1305,12 +1340,7 @@ solve_equation = POISSON; /* POISSON, HELMHOLTZ */
   RBT_init(&rt,&equ,&lt,&print_detail,&delete_triangle);
 
 
-/* plotting */
- plot_mesh=0;
- plot_cont=1;
- plot_grad=0;
- plot_legend=0;
- 
+
  /* set eig_array to null */
  if((eig_array= (MY_DOUBLE*) calloc((size_t)degree_of_freedom,sizeof(MY_DOUBLE)))==0){
    fprintf(stderr, "%s: %d: no free memory\n", __FILE__,__LINE__);
@@ -1325,11 +1355,9 @@ solve_equation = POISSON; /* POISSON, HELMHOLTZ */
 int 
 main(int argc, char **argv)
 {
-#ifdef USE_GTK
 /* gtkglext */
  GtkWidget *window;
  GdkGLConfig *glconfig;
-#endif
 
 
 /* use getopt to parse commandline */
@@ -1341,7 +1369,6 @@ if ( input_cord_filename ) {
 /*free_everything(); */
 
 
-#ifdef USE_GTK
  /* intialiaze gtk */
  gtk_init(&argc,&argv);
  /* intialize GtkGlExt */
@@ -1353,7 +1380,6 @@ if ( input_cord_filename ) {
  window=create_window(glconfig);
  gtk_widget_show(window);
  gtk_main();
-#endif /* !USE_GTK */
   return(0);
 }
 
