@@ -13,7 +13,7 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-  $Id: solve.c,v 1.33 2004/08/20 14:20:50 sarod Exp $
+  $Id: solve.c,v 1.34 2004/11/16 13:02:44 sarod Exp $
 */
 
 
@@ -22,7 +22,6 @@
 #include <config.h>
 #endif
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h> /* for sqrt() */
@@ -160,11 +159,11 @@ build( MY_DOUBLE **P, MY_DOUBLE *q, MY_DOUBLE *x, MY_DOUBLE *y, MY_DOUBLE *phi,
   }
 	
   /* now initialize P[][] and q[] */
-  for ( i = 0; i < NUN; i++) {
+/*  for ( i = 0; i < NUN; i++) {
     q[i] = 0;
     for ( j = 0; j <= i; j++) 
       P[i][j] = 0;
-  }
+  } */
   
 #ifdef DEBUG
 	for  ( i = 0; i< NN; i++)
