@@ -14,27 +14,16 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-  $Id: types.h,v 1.47 2004/10/18 21:10:08 sarod Exp $
+  $Id: types.h,v 1.51 2004/11/17 01:34:01 sarod Exp $
 */
 
 #ifndef TYPES_H 
 #define TYPES_H 1
-/*
-#define USE_GLUT 
-*/
-
-#define USE_GTK 
-/**/
-#ifdef USE_GLUT
-#include <GL/glut.h>
-#endif /* !GLUT */
-#ifdef USE_GTK
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkgl.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
-#endif
 
 
 #define ONE_OVER_TWELVE 0.0833333333333333333333f
@@ -45,10 +34,6 @@
 #define M_PI  3.14159265358979323846  /* pi */
 #endif /* M_PI */
 
-#ifndef sqrtf
-#define sqrtf(x) sqrt(x)
-#endif 
-
 #define TOL 0.000000001f
 /*
  *            bitree.c 
@@ -625,7 +610,6 @@ extern int plot_mesh, plot_cont, plot_fill, plot_grad, plot_legend;
 /*
  *           graphics.c 
  */
-#ifdef USE_GTK
 /* main window creation */
 extern GtkWidget*
 create_window(GdkGLConfig *glconfig);
@@ -634,7 +618,6 @@ create_window(GdkGLConfig *glconfig);
 extern GdkGLConfig *
 configure_gl(void);
 
-#endif /* !USE_GTK */
 
 /*
  *           rbt.c 
@@ -696,7 +679,7 @@ extern MY_DOUBLE g_gradient_limit;
 /* 
  * solve.c 
  */
-typedef enum { POISSON, HELMHOLTZ, HELMHOLTZ_INHOMO, HELMHOLTZ_FREQ, HELMHOLTZ_BETA } eq_type; /* type of equation to solve */
+typedef enum { POISSON, POISSON_SPARSE, HELMHOLTZ, HELMHOLTZ_INHOMO, HELMHOLTZ_FREQ, HELMHOLTZ_BETA } eq_type; /* type of equation to solve */
 /* HELMHOLTZ: homogeneous wave eqn. HELMHOLTZ_INHOMO: inhomogeneous
   HELMHOLTZ_FREQ: given beta, find cutoff 
   HELMHOLTZ_BETA: given freq. find beta */
@@ -728,6 +711,9 @@ print_mesh_eps(const char* filename);
 /* printing mesh as an ASCII file */
 extern void
 print_mesh_ascii(const char* filename);
+/* printing potentials as ACII file*/
+extern void
+print_potential(const char* filename);
 /* plotting gradient */
 extern void
 plot_gradient(void);
@@ -825,4 +811,64 @@ buildup_hash_table_and_equation(void);
 extern MY_DOUBLE
 calc_integral(int con);
 
+/* 
+ * spmat.h
+ */
+/* sparse matrix routines */
+typedef struct SPMat_ {
+   int N; /* size is N by N */
+   RBT_tree **rt;
+} SPMat;
+
+/* intialize a matrix */
+extern int
+SPM_init( SPMat *sM, int N ); /* N - N by N sparse matrix M */
+
+/* add z to i,j location of M */
+/* initially assumed zero */
+/* i,j has to be within [0,N-1] */
+extern int
+SPM_add( SPMat *sM, int i, int j,  MY_DOUBLE z);
+
+/* myltiply i,j location of M  by z */
+/* initially assumed zero */
+/* i,j has to be within [0,N-1] */
+extern int
+SPM_mult( SPMat *sM, int i, int j,  MY_DOUBLE z);
+
+/* returns size of M, or value of N */
+extern int
+SPM_dim(SPMat *sM);
+
+/* delete matrix M */
+extern int
+SPM_destroy(SPMat *sM);
+
+
+/* copy row i of M to vector v */
+/* v size N by 1 */
+extern int 
+SPM_row(SPMat *sM, MY_INT i, MY_DOUBLE *v);
+
+/* copy column i of M to vector v */
+/* v size N by 1 */
+/* note column access is more expensive than row access */
+extern int 
+SPM_col(SPMat *sM, MY_INT i, MY_DOUBLE *v);
+
+/* returns the value at location (i,j)
+ of the matrix or zero if none found */
+extern MY_DOUBLE 
+SPM_e(SPMat *sM, MY_INT i, MY_INT j);
+
+/* replaces the value at location (i,j)
+ of the matrix with z */
+extern int
+SPM_eq(SPMat *sM, MY_INT i, MY_INT j,MY_DOUBLE z);
+
+/* sparse solver using conjugate gradients for
+ Poisson equation */
+extern int 
+re_number_and_solve_poisson_sparse(void);
+
 #endif /* ! TYPES_H*/
